@@ -7,10 +7,17 @@
 # This is free software; you can do what the LICENCE file allows you to.
 #
 import doctest
+from dataclasses import dataclass
+from typing import Any
+
+from hypothesis import given
+from hypothesis import strategies as s
+from hypothesis.strategies import SearchStrategy
+
 import xotless.immutables
 from xotless.immutables import ImmutableWrapper
 
-from .support import captured_stdout, captured_stderr
+from .support import captured_stderr, captured_stdout
 
 
 def test_doctests():
@@ -47,7 +54,7 @@ def test_wrap_properties():
     from dataclasses import dataclass
     from datetime import datetime, timedelta
 
-    @dataclass
+    @dataclass(frozen=True)
     class Commodity:
         start_date: datetime
         duration: timedelta
@@ -63,6 +70,9 @@ def test_wrap_properties():
     ).replace(start_date=now, duration=day)
     assert item.end_date == now + day
 
+    commodity = Commodity(datetime.utcnow(), timedelta(1))
+    assert hash(commodity) == hash(ImmutableWrapper(commodity))
+
 
 def test_wrap_descriptors():
     class Descriptor:
@@ -76,3 +86,25 @@ def test_wrap_descriptors():
 
     item = ImmutableWrapper(Item(), wrap_descriptors=True)
     assert item.identity == id(item)
+
+
+anything: SearchStrategy[Any] = s.integers() | s.floats() | s.text()
+anything = (
+    anything
+    | s.dictionaries(s.text(), anything)
+    | s.tuples(anything)
+    | s.lists(anything)
+)
+
+
+@dataclass
+class Obj:
+    truth: bool
+
+    def __bool__(self):
+        return self.truth
+
+
+@given(anything | s.from_type(Obj))
+def test_boolean_values_basic(val):
+    assert bool(ImmutableWrapper(val)) == bool(val)
